function [JO2] = ox_flux(c,O2);

%%
% FUNCTION ox_flux: computes oxygen consumption rate with given state
% variables
%
% INPUTS: 
%   c      -         vector of state variables
%   O2     -         oxygen concentration (M) - Attn: M == mol (l water)^{-1})
%
% OUTPUTS:
%   JO2    -         oxygen consumption rate (mol s^{-1} (l cell)^{-1}
%%

% Fixed parameters
%% physicochemical parameters
RT = 2.5775;                    % gas constant times temperature (kJ mol^{-1})
F = 0.096484;                   % Faraday's constant (kJ mol^{-1} mV^{-1})
dG_C4o = -122.94;               % standard free energy, complex IV (kJ mol^{-1})
%% fixed concentrations
pH_c = 7.0;                     % cytosol pH
H_c = 10^(-pH_c);               % H+ concentration in cytoplasm (mol (l cytolasm water)^{-1})
%% Structure/Volume parameters
Vmito = 0.056;                  % mitochondrial volume (ml mito / ml cell)
Vcyto = 0.894;                  % cytoplasm volume(ml cyto / ml cell)
Rm_cyto = Vmito / Vcyto;        % Volume ratio of mito volume to cytoplasm volume
Rm_cell = Vmito;                % Volume ratio of mito volume to cell volume
Rc_cell = Vcyto;                % Volume ratio of cytosol volume to cell volume
%% fixed concentration pools
Ctot   = 2.70e-3;               % total cytochrom C concentration (mol (l IM water)^{-1})
CMb = 200e-6;                   % Myoglobin concentration (mol (l cell)^{-1})
a_3  = 1.74e-6;                 % oxygen solubility in cell (M mmHg^{-1})
C50  = a_3*(2.39);              % oxy-myoglobin 1/2 saturation (M)
%% Adjustable parameters:
x_C4   = 6.766e-5;              % complex IV activity (mol s^{-1} M^{-1} (l mito)^{-1})
%% Other parameters:
k_O2   = 1.2e-4;                % kinetic constant for complex IV (M)


% State variables required for computation
pH_x = c(1); H_x = 10^(-pH_x);
Cox  = c(6);
Cred = Ctot - Cox;
dPsi = c(27);

% H in IM space (assuming mito. outer membrance is permeable)
H_i  = H_c;
% Membrane proton motive force:
dG_H = F*dPsi + RT*log(H_i/H_x);
% Computing the standard free energy of reactions under certain H_x
dG_C4op = dG_C4o - 2*RT*log(H_x/1e-7); % complex IV

% Computing flux on complex IV
if O2 > 1e-12
  J_C4 = x_C4*(O2/(O2+k_O2))*(Cred/Ctot)*( exp(-(dG_C4op+2*dG_H)/(2*RT))*Cred*(O2^0.25) - Cox*exp(F*dPsi/RT) );
else
  J_C4 = 0;
end

% Convert complex IV flux into consumption rate of O2
JO2  = Rm_cell*J_C4/2; % O2 consumption in mole sec^{-1} (liter cell volume)^{-1}


